@@ -19,22 +19,22 @@ pub fn generate(shell: Shell, args: &[String]) -> Result<String> {
     cmds.extend(args.iter().map(|v| v.as_str()));
     let output = match shell {
         Shell::Bash => {
-            let code = format!("complete -F _argc_complete {}", cmds.join(" "));
+            let code = format!("complete -F _argc_completer {}", cmds.join(" "));
             format!("{BASH_SCRIPT}\n{code}\n",)
         }
         Shell::Zsh => {
-            let code = format!("compdef _argc_complete {}", cmds.join(" "));
+            let code = format!("compdef _argc_completer {}", cmds.join(" "));
             format!("{ZSH_SCRIPT}\n{code}\n",)
         }
         Shell::Powershell => {
-            let lines: Vec<String> = cmds.iter().map(|v| format!("Register-ArgumentCompleter -Native -ScriptBlock $_argc_complete -CommandName {v} ")).collect();
+            let lines: Vec<String> = cmds.iter().map(|v| format!("Register-ArgumentCompleter -Native -ScriptBlock $_argc_completer -CommandName {v} ")).collect();
             let code = lines.join("\n");
             format!("{POWERSHELL_SCRIPT}\n{code}\n",)
         }
         Shell::Fish => {
             let lines: Vec<String> = cmds
                 .iter()
-                .map(|v| format!(r#"complete -x -c {v} -a "(_argc_complete)""#))
+                .map(|v| format!(r#"complete -x -c {v} -a "(_argc_completer)""#))
                 .collect();
             let code = lines.join("\n");
             format!("{FISH_SCRIPT}\n{code}\n",)
@@ -42,7 +42,7 @@ pub fn generate(shell: Shell, args: &[String]) -> Result<String> {
         Shell::Elvish => {
             let lines: Vec<String> = cmds
                 .iter()
-                .map(|v| format!(r#"set edit:completion:arg-completer[{v}] = $argc-complete~"#))
+                .map(|v| format!(r#"set edit:completion:arg-completer[{v}] = $argc-completer~"#))
                 .collect();
             let code = lines.join("\n");
             format!("{ELVISH_SCRIPT}\n{code}\n",)
@@ -52,23 +52,20 @@ pub fn generate(shell: Shell, args: &[String]) -> Result<String> {
             format!(
                 r###"{NUSHELL_SCRIPT}
 
-let argc_scripts = {code}
+let _argc_scripts = {code}
 
 let external_completer = {{|spans| 
-    if (not ($argc_scripts | find $spans.0 | is-empty)) {{
-        argc_complete $spans
+    if (not ($_argc_scripts | find $spans.0 | is-empty)) {{
+        _argc_completer $spans
     }} else {{
         # default completer
     }}
 }}
 
-let-env config = {{
-  completions: {{
-    external: {{
-      enable: true
-      completer: $external_completer
-    }}
-  }}
+$env.config.completions.external = {{
+    enable: true
+    max_results: 100
+    completer: $external_completer
 }}
 "###,
             )
