@@ -284,6 +284,13 @@ impl FlagOptionParam {
             self.arg_value_names.len()
         }
     }
+
+    pub(crate) fn describe_head(&self) -> &str {
+        match self.describe.split_once('\n') {
+            Some((v, _)) => v,
+            None => self.describe.as_str(),
+        }
+    }
 }
 
 #[derive(Debug, PartialEq, Eq, Clone, Serialize)]
@@ -378,6 +385,13 @@ impl PositionalParam {
             Some(ArgcValue::PositionalSingle(name, must_get_first(values)))
         }
     }
+
+    pub(crate) fn describe_head(&self) -> &str {
+        match self.describe.split_once('\n') {
+            Some((v, _)) => v,
+            None => self.describe.as_str(),
+        }
+    }
 }
 
 fn render_name(
