@@ -1,4 +1,3 @@
-use anyhow::{anyhow, Context, Result};
 use convert_case::{Boundary, Converter, Pattern};
 use std::{
     env,
@@ -24,10 +23,6 @@ pub fn escape_shell_words(value: &str) -> String {
     shell_words::quote(value).to_string()
 }
 
-pub fn split_shell_words(s: &str) -> Result<Vec<String>> {
-    shell_words::split(s).with_context(|| anyhow!("Failed to split shell words"))
-}
-
 pub fn is_choice_value_terminate(c: char) -> bool {
     c == '|' || c == ']'
 }
@@ -62,22 +57,37 @@ pub fn get_bash_path() -> Option<PathBuf> {
     which("bash").ok()
 }
 
-pub fn run_param_fns(script_file: &str, param_fns: &[&str], line: &str) -> Option<Vec<String>> {
+pub fn run_param_fns(
+    script_file: &str,
+    param_fns: &[&str],
+    args: &[String],
+) -> Option<Vec<String>> {
     let shell = get_shell_path()?;
+    let shell_extra_args = if shell
+        .file_stem()
+        .map(|v| v.to_string_lossy().to_lowercase().contains("bash"))
+        .unwrap_or_default()
+    {
+        vec!["--noprofile".to_string(), "--norc".to_string()]
+    } else {
+        vec![]
+    };
     let path_env = path_env_with_exe();
     let handles: Vec<_> = param_fns
         .iter()
         .map(|param_fn| {
             let script_file = script_file.to_string();
-            let line = line.to_string();
+            let args: Vec<String> = args.to_vec();
             let path_env = path_env.clone();
             let param_fn = param_fn.to_string();
             let shell = shell.clone();
+            let shell_extra_args = shell_extra_args.clone();
             thread::spawn(move || {
                 process::Command::new(shell)
+                    .args(shell_extra_args)
                     .arg(&script_file)
                     .arg(&param_fn)
-                    .arg(line)
+                    .args(args)
                     .env("PATH", path_env)
                     .output()
                     .ok()
